netapp_ontap.models.consistency_group_child API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.consistency_group_child`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ConsistencyGroupChildSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ConsistencyGroupChild object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `application: ConsistencyGroupApplication GET POST PATCH`

    The application field of the consistency_group_child.

  `links: SelfLink GET`

    The links field of the consistency_group_child.

  `luns: List[ConsistencyGroupLun] GET POST PATCH`

    The LUNs array can be used to create or modify LUNs in a consistency group on a new or existing volume that is a member of the consistency group. LUNs are considered members of a consistency group if they are located on a volume that is a member of the consistency group. The maximum number of items for this array is 16. The maximum number of items for this array is 256.

  `name: str GET POST`

    Name of the consistency group. The consistency group name must be unique within an SVM.
    If not provided and the consistency group contains only one volume, the name will be generated based on the volume name. If the consistency group contains more than one volume, the name is required.

  `namespaces: List[ConsistencyGroupNamespaces] GET POST PATCH`

    An NVMe namespace is a collection of addressable logical blocks presented to hosts connected to the SVM using the NVMe over Fabrics protocol. In ONTAP, an NVMe namespace is located within a volume. Optionally, it can be located within a qtree in a volume.
    An NVMe namespace is created to a specified size using thin or thick provisioning as determined by the volume on which it is created. NVMe namespaces support being cloned. An NVMe namespace cannot be renamed, resized, or moved to a different volume. NVMe namespaces do not support the assignment of a QoS policy for performance management, but a QoS policy can be assigned to the volume containing the namespace. See the NVMe namespace object model to learn more about each of the properties supported by the NVMe namespace REST API.
    An NVMe namespace must be mapped to an NVMe subsystem to grant access to the subsystem's hosts. Hosts can then access the NVMe namespace and perform I/O using the NVMe over Fabrics protocol. The maximum number of items for this array is 16. The maximum number of items for this array is 256.

  `parent_consistency_group: ConsistencyGroup GET`

    The parent_consistency_group field of the consistency_group_child.

  `provisioning_options: ConsistencyGroupProvisioningOptions POST PATCH`

    Options that are applied to the operation.

  `qos: ConsistencyGroupQos GET POST PATCH`

    The qos field of the consistency_group_child.

  `restore_to: ConsistencyGroupConsistencyGroupsRestoreTo PATCH`

    Use to restore a consistency group to a previous snapshot

  `snapshot_policy: SnapshotPolicy GET POST PATCH`

    The snapshot policy of the consistency group.
    This is the dedicated consistency group snapshot policy, not an aggregation of the volume granular snapshot policy.

  `space: ConsistencyGroupSpace GET`

    The space field of the consistency_group_child.

  `svm: Svm GET POST`

    The svm field of the consistency_group_child.

  `tags: List[str] GET POST PATCH`

    Tags are an optional way to track the uses of a resource. Tag values must be formatted as key:value strings.

    Example: ["team:csi","environment:test"]

  `tiering: ConsistencyGroupTiering GET POST`

    The tiering field of the consistency_group_child.

  `uuid: str GET`

    The unique identifier of the consistency group. The UUID is generated by ONTAP when the consistency group is created.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412

  `volumes: List[ConsistencyGroupVolumes] GET POST PATCH`

    A consistency group is a mutually exclusive aggregation of volumes or other consistency groups. A volume can only be associated with one direct parent consistency group.
    The volumes array can be used to create new volumes in the consistency group, add existing volumes to the consistency group, or modify existing volumes that are already members of the consistency group.
    The total number of volumes across all child consistency groups contained in a consistency group is constrained by the same limit.